==> Botan-1.3.5.tgz: Botan-1.3.5/src/pk_util.cpp <==
/*************************************************
* PK Utility Classes Source File                 *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/pk_util.h>

namespace Botan {

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return pad(msg, msg_len, key_bits);
   }

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const SecureVector<byte>& msg,
                               u32bit key_bits) const
   {
   return pad(msg, msg.size(), key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return unpad(msg, msg_len, key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const SecureVector<byte>& msg,
                               u32bit key_bits) const
   {
   return unpad(msg, msg.size(), key_bits);
   }

/*************************************************
* Default signature decoding                     *
*************************************************/
bool EMSA::verify(const SecureVector<byte>& coded,
                  const SecureVector<byte>& raw,
                  u32bit key_bits) throw()
   {
   try {
      return (coded == encoding_of(raw, key_bits));
      }
   catch(Invalid_Argument)
      {
      return false;
      }
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len, const OctetString& secret,
                            const std::string& salt) const
   {
   return derive_key(key_len, secret, secret.length(), salt);
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len, const OctetString& secret,
                            const byte salt[], u32bit salt_len) const
   {
   return derive(key_len, secret, secret.length(), salt, salt_len);
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len,
                            const byte secret[], u32bit secret_len,
                            const std::string& salt) const
   {
   return derive(key_len, secret, secret_len,
                          (const byte*)salt.c_str(), salt.length());
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len,
                            const byte secret[], u32bit secret_len,
                            const byte salt[], u32bit salt_len) const
   {
   return derive(key_len, secret, secret_len, salt, salt_len);
   }

}

==> Botan-1.3.14.tgz: Botan-1.3.14/src/pk_util.cpp <==
/*************************************************
* PK Utility Classes Source File                 *
* (C) 1999-2004 The Botan Project                *
*************************************************/

#include <botan/pk_util.h>

namespace Botan {

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return pad(msg, msg_len, key_bits);
   }

/*************************************************
* Encode a message                               *
*************************************************/
SecureVector<byte> EME::encode(const MemoryRegion<byte>& msg,
                               u32bit key_bits) const
   {
   return pad(msg, msg.size(), key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const byte msg[], u32bit msg_len,
                               u32bit key_bits) const
   {
   return unpad(msg, msg_len, key_bits);
   }

/*************************************************
* Decode a message                               *
*************************************************/
SecureVector<byte> EME::decode(const MemoryRegion<byte>& msg,
                               u32bit key_bits) const
   {
   return unpad(msg, msg.size(), key_bits);
   }

/*************************************************
* Default signature decoding                     *
*************************************************/
bool EMSA::verify(const MemoryRegion<byte>& coded,
                  const MemoryRegion<byte>& raw,
                  u32bit key_bits) throw()
   {
   try {
      return (coded == encoding_of(raw, key_bits));
      }
   catch(Invalid_Argument)
      {
      return false;
      }
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len, const OctetString& secret,
                            const std::string& salt) const
   {
   return derive_key(key_len, secret.begin(), secret.length(), salt);
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len, const OctetString& secret,
                            const byte salt[], u32bit salt_len) const
   {
   return derive(key_len, secret.begin(), secret.length(), salt, salt_len);
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len,
                            const byte secret[], u32bit secret_len,
                            const std::string& salt) const
   {
   return derive(key_len, secret, secret_len,
                          (const byte*)salt.c_str(), salt.length());
   }

/*************************************************
* Derive a key                                   *
*************************************************/
OctetString KDF::derive_key(u32bit key_len,
                            const byte secret[], u32bit secret_len,
                            const byte salt[], u32bit salt_len) const
   {
   return derive(key_len, secret, secret_len, salt, salt_len);
   }

}
